=======================
ReactiveX eXtensions
=======================

.. image:: https://img.shields.io/pypi/v/rxx.svg
    :target: https://pypi.org/project/rxx/
    :alt: PyPI

.. image:: https://github.com/maki-nage/rxx/actions/workflows/ci.yml/badge.svg
    :target: https://github.com/maki-nage/rxx/actions/workflows/ci.yml
    :alt: Github WorkFlows

.. image:: https://coveralls.io/repos/github/maki-nage/rxx/badge.svg?branch=master
    :target: https://coveralls.io/github/maki-nage/rxx?branch=master
    :alt: Code Coverage

.. image:: https://readthedocs.org/projects/rxx/badge/?version=latest
    :target: https://rxx.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation


Additional ReactiveX operators.

Get Started
============

Installation
=============

Rxx is available on PyPi and can be installed with pip:

.. code:: console

    python3 -m pip install rxx
